# Standard lib imports
import os
from datetime import timedelta
# Third-party imports
from dotenv import load_dotenv
# BITSON imports

BASEDIR = os.path.dirname(os.path.abspath(__file__))

ENV_VARS = os.path.join(BASEDIR, ".env")
load_dotenv(ENV_VARS)


class Config:
    """Base config class"""
    PROJECT_NAME = os.environ.get('PROJECT_NAME')
    CURRENT_DIR = os.path.dirname(os.path.abspath(__file__))

    DB_SERVICE = os.environ.get('DB_SERVICE')
    DB_USER = os.environ.get('DB_USER')
    DB_PASSWORD = os.environ.get('DB_PASSWORD')
    DB_HOST = os.environ.get('DB_HOST')
    DB_PORT = os.environ.get('DB_PORT')
    DB_NAME = os.environ.get('DB_NAME')
    # DB_URI = '{service}://{user}:{password}@{host}:{port}/{db}'.format(
    #     service=DB_SERVICE,
    #     user=DB_USER,
    #     password=DB_PASSWORD,
    #     host=DB_HOST,
    #     port=DB_PORT,
    #     db=DB_NAME
    # )
    '''cuando se use sqlite se hace asi'''
    DB_URI = '{service}:///{dir}'.format(
        service=DB_SERVICE,
        dir=os.path.join(os.path.dirname(__file__), DB_NAME+'.db')
    )



    LOG_IN_DB = {
        'OPTIONS': [],
        'GET': [],
        'POST': [201, 200, 400],
        'PUT': [200, 400],
        'DELETE': [204, 400]
    }

    SQLALCHEMY_TRACK_MODIFICATIONS = False
    SLOW_QUERY_TIMEOUT = 0.5
    SQLALCHEMY_RECORD_QUERIES = False

    WTF_CSRF_ENABLED = False


    @staticmethod
    def init_app(app):
        pass


class DevelopmentConfig(Config):
    DEBUG = True
    TESTING = False

    SQLALCHEMY_DATABASE_URI = os.environ.get('DEV_DB_URL') or Config.DB_URI

    MAIL_FLUSH_INTERVAL = 60  # one minute

config = {
    'development': DevelopmentConfig,
    'default': DevelopmentConfig
}